pub struct Config {
pub search_dirs: Vec<SearchDirEntry>,
pub session: SessionConfig,
pub theme: ThemeConfig,
pub keys: KeysConfig,
pub agent: AgentConfig,
}Fields
search_dirs: Vec<SearchDirEntry>Directories to scan for git repositories. Each directory can be scanned to a specified depth, with a default of 1 (i.e. just the top level).
Supports ~ for the home directory. For example:
search_dirs = ["~/Development", { path = "~/Work", depth = 2 }]session: SessionConfigLayout when creating a new tmux session.
theme: ThemeConfigColor theme configuration.
keys: KeysConfigKey binding configuration.
To unbind an inherited key mapping, assign it to noop.
agent: AgentConfigAgent detection configuration.
Implementations